import {expect} from 'chai'
import sinon from 'sinon'
import trackByWindowObject, {KEY} from '../../src/analytics/trackByWindowObject'

describe('#trackByWindowObject', () => {
  beforeEach(() => {
    window.analytics = {}
    window.analytics.track = sinon.spy()
  })

  describe(`when no window.${KEY} object is set`, () => {
    it('should not send any track event', () => {
      trackByWindowObject()

      sinon.assert.callCount(window.analytics.track, 0)
    })
  })

  describe(`when window.${KEY} object is set`, () => {
    it('should track the event', () => {
      window[KEY] = {
        segment_event_name: 'My Fake Event Name',
        prop1: 'prop1',
        prop2: 'prop2'
      }

      trackByWindowObject()

      sinon.assert.callCount(window.analytics.track, 1)
      expect(window.analytics.track.getCall(0).args[0]).to.equal(
        'My Fake Event Name'
      )
      expect(window.analytics.track.getCall(0).args[1]).to.deep.equal({
        prop1: 'prop1',
        prop2: 'prop2'
      })
    })
  })
})
