import {expect} from 'chai'
import getTealiumConfig from '../../../src/vendors/tealium/config'

describe('getTealiumConfig', () => {
  it('should return the config if tealium is enabled in prod env', () => {
    const expectedTealiumConfig = {
      tealium: {
        consents: {
          purposes: [1, 2, 3, 4, 5, 6, 7, 8, 9, 10],
          specialFeatureOptions: [1]
        },
        script: '//tags.tiqcdn.com/utag/schibsted/infojobs/prod/utag.js'
      }
    }

    const {config: tealiumConfig} = getTealiumConfig({
      portal: 'es',
      environment: ''
    })
    expect(tealiumConfig).to.be.deep.equal(expectedTealiumConfig)
  })

  it('should return the config if tealium is enabled for qa env', () => {
    const expectedTealiumConfig = {
      tealium: {
        script: '//tags.tiqcdn.com/utag/schibsted/infojobs/qa/utag.js',
        consents: {
          purposes: [1, 2, 3, 4, 5, 6, 7, 8, 9, 10],
          specialFeatureOptions: [1]
        }
      }
    }

    const {config: tealiumConfig} = getTealiumConfig({
      portal: 'es',
      environment: 'qaaws'
    })
    expect(tealiumConfig).to.be.deep.equal(expectedTealiumConfig)
  })

  it('should return the config if tealium is enabled for pre', () => {
    const expectedTealiumConfig = {
      tealium: {
        script: '//tags.tiqcdn.com/utag/schibsted/infojobs/qa/utag.js',
        consents: {
          purposes: [1, 2, 3, 4, 5, 6, 7, 8, 9, 10],
          specialFeatureOptions: [1]
        }
      }
    }

    const {config: tealiumConfig} = getTealiumConfig({
      portal: 'es',
      environment: 'sbx'
    })
    expect(tealiumConfig).to.be.deep.equal(expectedTealiumConfig)
  })

  it('should return an empty object if tealium is not enabled', () => {
    const expectedTealiumConfig = {}

    const {config: tealiumConfig} = getTealiumConfig({
      portal: 'es',
      environment: '',
      queryParams: '?disable-tealium'
    })

    expect(tealiumConfig).to.be.deep.equal(expectedTealiumConfig)
  })

  it('should return the config if tealium is enabled in prod env for it portal', () => {
    const expectedTealiumConfig = {
      tealium: {
        consents: {
          purposes: [1, 2, 3, 4, 5, 6, 7, 8, 9, 10],
          specialFeatureOptions: [1]
        },
        script: '//tags.tiqcdn.com/utag/schibsted/infojobs.it/prod/utag.js'
      }
    }

    const {config: tealiumConfig} = getTealiumConfig({
      portal: 'it',
      environment: ''
    })
    expect(tealiumConfig).to.be.deep.equal(expectedTealiumConfig)
  })

  it('should return the config if tealium is enabled for qa env for it portal', () => {
    const expectedTealiumConfig = {
      tealium: {
        script: '//tags.tiqcdn.com/utag/schibsted/infojobs.it/qa/utag.js',
        consents: {
          purposes: [1, 2, 3, 4, 5, 6, 7, 8, 9, 10],
          specialFeatureOptions: [1]
        }
      }
    }

    const {config: tealiumConfig} = getTealiumConfig({
      portal: 'it',
      environment: 'qaaws'
    })
    expect(tealiumConfig).to.be.deep.equal(expectedTealiumConfig)
  })

  it('should return the config if tealium is enabled for pre for it portal', () => {
    const expectedTealiumConfig = {
      tealium: {
        script: '//tags.tiqcdn.com/utag/schibsted/infojobs.it/qa/utag.js',
        consents: {
          purposes: [1, 2, 3, 4, 5, 6, 7, 8, 9, 10],
          specialFeatureOptions: [1]
        }
      }
    }

    const {config: tealiumConfig} = getTealiumConfig({
      portal: 'it',
      environment: 'sbx'
    })
    expect(tealiumConfig).to.be.deep.equal(expectedTealiumConfig)
  })

  it('should return an empty object if tealium is not enabled for it portal', () => {
    const expectedTealiumConfig = {}

    const {config: tealiumConfig} = getTealiumConfig({
      portal: 'it',
      environment: '',
      queryParams: '?disable-tealium'
    })

    expect(tealiumConfig).to.be.deep.equal(expectedTealiumConfig)
  })
})
